@@ -5,9 +5,9 @@
 
 #include "terminal-type-builtins.h"
 
-/* enumerations from "/usr/src/ports/gnome-terminal/gnome-terminal-3.18.2-1.x86_64/src/gnome-terminal-3.18.2/src/terminal-enums.h" */
+/* enumerations from "/usr/src/ports/gnome-terminal/gnome-terminal-3.22.2-1.x86_64/src/gnome-terminal-3.22.2/src/terminal-enums.h" */
 
-#include "/usr/src/ports/gnome-terminal/gnome-terminal-3.18.2-1.x86_64/src/gnome-terminal-3.18.2/src/terminal-enums.h"
+#include "/usr/src/ports/gnome-terminal/gnome-terminal-3.22.2-1.x86_64/src/gnome-terminal-3.22.2/src/terminal-enums.h"
 
 GType
 terminal_new_terminal_mode_get_type (void)
@@ -91,6 +91,27 @@ terminal_cjk_width_get_type (void)
   return g_define_type_id__volatile;
 }
 
+GType
+terminal_theme_variant_get_type (void)
+{
+  static volatile gsize g_define_type_id__volatile = 0;
+ 
+  if (g_once_init_enter (&g_define_type_id__volatile)) {
+    static const GEnumValue values[] = {
+      { TERMINAL_THEME_VARIANT_SYSTEM, "TERMINAL_THEME_VARIANT_SYSTEM", "system" },
+      { TERMINAL_THEME_VARIANT_LIGHT, "TERMINAL_THEME_VARIANT_LIGHT", "light" },
+      { TERMINAL_THEME_VARIANT_DARK, "TERMINAL_THEME_VARIANT_DARK", "dark" },
+      { 0, NULL, NULL }
+    };
+    GType g_define_type_id = \
+       g_enum_register_static (/* g_intern_static_string */ ("TerminalThemeVariant"), values);
+      
+    g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
+  }
+    
+  return g_define_type_id__volatile;
+}
+
 
 
 /* Generated data ends here */
